@@ -25,16 +25,21 @@
 #  include "config.h"
 #endif
 
+#include <sys/types.h>
+#include <sys/time.h>
+#include <X11/Xlib.h>
 #include <glib.h>
 
 void getMouseXY (Window, int *, int *);
 Window getMouseWindow (Window);
 GC createGC (Colormap, char *, int, XFontStruct *, int, gboolean);
-void sendClientMessage (Window, Atom, long, int);
+void sendClientMessage (Window, Atom, Atom);
 void MyXGrabServer (void);
 void MyXUngrabServer (void);
+gboolean MyCheckWindow(Window);
 Window setTmpEventWin (int, int, unsigned int, unsigned int, long);
 void removeTmpEventWin (Window);
 void placeSidewalks(gboolean);
+Time stashEventTime (Time, XEvent *);
 
 #endif /* INC_MISC_H */
